sequencetools.retain_sequence_elements_at_indices_cyclically
============================================================

.. autofunction:: abjad.tools.sequencetools.retain_sequence_elements_at_indices_cyclically.retain_sequence_elements_at_indices_cyclically
